# Changelog

## [v0.3.10](https://github.com/astrochun/github-stats-pages/tree/v0.3.10) (2021-05-02)

**Implemented enhancements:**
 - Feature: Add GitHub repo description on repo pages [#55](http://github.com/astrochun/github-stats-pages/pull/55)

**Closed issues:**
 - Chore: Refactoring of stats_plots [#51](http://github.com/astrochun/github-stats-pages/issues/51)
 - Feature: Add GitHub repo description on repo pages [#54](http://github.com/astrochun/github-stats-pages/issues/54)

**Merged pull requests:**
 - Chore: Refactoring of stats_plots [#53](http://github.com/astrochun/github-stats-pages/pull/53)


## [v0.3.9](https://github.com/astrochun/github-stats-pages/tree/v0.3.9) (2021-04-28)

**Closed issues:**
 - Chore: Add hidden HTML explaining each HTML files [#38](http://github.com/astrochun/github-stats-pages/issues/38)
 - Enhancement: Adjust timeline plot to line up for both clones and daily traffic [#36](http://github.com/astrochun/github-stats-pages/issues/36)

**Merged pull requests:**
 - Chore: Add hidden HTML explaining each HTML files [#49](http://github.com/astrochun/github-stats-pages/pull/49)
 - Enhancement: Adjust timeline plot to line up for both clones and daily traffic [#50](http://github.com/astrochun/github-stats-pages/pull/50)


## [v0.3.8](https://github.com/astrochun/github-stats-pages/tree/v0.3.8)

**Implemented enhancements:**
 - Feature: Support for markdown table to HTML [#48](http://github.com/astrochun/github-stats-pages/pull/48)

**Closed issues:**
 - Chore: Add Shields.io logo [#41](http://github.com/astrochun/github-stats-pages/issues/41)
 - Chore: Add FAQs in documentation [#37](http://github.com/astrochun/github-stats-pages/issues/37)
 - Feature: Support for markdown table to HTML [#47](http://github.com/astrochun/github-stats-pages/issues/47)

**Merged pull requests:**
 - Chore: Add Shields.io logo [#45](http://github.com/astrochun/github-stats-pages/pull/45)
 - Chore: Add FAQs in documentation [#46](http://github.com/astrochun/github-stats-pages/pull/46)


## [v0.3.7](https://github.com/astrochun/github-stats-pages/tree/v0.3.7) (2021-04-25)

**Closed issues:**
 - Docs: Fix YAML in README.md to use repository_owner over actor, GitHub env [#43](http://github.com/astrochun/github-stats-pages/issues/43)

**Merged pull requests:**
 - Docs: Fix YAML in README.md to use repository_owner over actor, GitHub env [#44](http://github.com/astrochun/github-stats-pages/pull/44)


## [v0.3.6](https://github.com/astrochun/github-stats-pages/tree/v0.3.6) (2021-04-21)

**Implemented enhancements:**
 - Enhancement: CI to search for uses and update README.md [#42](http://github.com/astrochun/github-stats-pages/pull/42)

**Closed issues:**
 - Enhancement: CI to search for uses and update README.md [#39](http://github.com/astrochun/github-stats-pages/issues/39)


## [v0.3.5](https://github.com/astrochun/github-stats-pages/tree/HEAD) (2021-04-16)

**Implemented enhancements:**
 - Update action docs for file push for GitHub repo [#35](http://github.com/astrochun/github-stats-pages/pull/35)

**Closed issues:**
 - Update action docs for file push for GitHub repo [#27](http://github.com/astrochun/github-stats-pages/issues/27)


## [v0.3.4](https://github.com/astrochun/github-stats-pages/tree/v0.3.4) (2021-04-11)

**Implemented enhancements:**
 -  Convert username README.md to HTML for index.html page [#34](http://github.com/astrochun/github-stats-pages/pull/34)

**Closed issues:**
 - Convert username README.md to HTML for index.html page [#33](http://github.com/astrochun/github-stats-pages/issues/33)


## [v0.3.3](https://github.com/astrochun/github-stats-pages/tree/v0.3.3) (2021-04-08)

**Fixed bugs:**
 - Bug: Fix page not found on repo pages [#30](http://github.com/astrochun/github-stats-pages/issues/30)

**Merged pull requests:**
 - Bug: Fix page not found on repo pages [#32](http://github.com/astrochun/github-stats-pages/pull/32)


## [v0.3.2](https://github.com/astrochun/github-stats-pages/tree/v0.3.2) (2021-04-04)

**Implemented enhancements:**
 - Change Container action to write static pages to a public folder [#29](http://github.com/astrochun/github-stats-pages/pull/29)

**Closed issues:**
 - Change Container action to write static pages to a public folder [#28](http://github.com/astrochun/github-stats-pages/issues/28)


## [v0.3.1](https://github.com/astrochun/github-stats-pages/tree/v0.3.1) (2021-04-02)

**Implemented enhancements:**
 - Implement a Docker Actions to gather stats and build pages [#26](http://github.com/astrochun/github-stats-pages/pull/26)

**Closed issues:**
 - Implement a Docker Actions to gather stats and build pages [#20](http://github.com/astrochun/github-stats-pages/issues/20)
 - Bug: Fix typo with exclude_repo in make_stats_plots [#24](http://github.com/astrochun/github-stats-pages/issues/24)
 - Fix namespace for include-repo and exclude-repo [#25](http://github.com/astrochun/github-stats-pages/issues/25)


## [v0.3.0](https://github.com/astrochun/github-stats-pages/tree/v0.3.0) (2021-03-23)

**Implemented enhancements:**
 - Module and script to generate plots; add CHANGELOG.md [#17](https://github.com/astrochun/github-stats-pages/pull/17)

**Closed issues:**
 - Module and script to generate plots [#16](http://github.com/astrochun/github-stats-pages/issues/16)
 - Add CHANGELOG.md [#18](http://github.com/astrochun/github-stats-pages/issues/18)

**Merged pull requests:**
 - Fix tag issue with CI run [#19](https://github.com/astrochun/github-stats-pages/pull/19)


## [v0.2.0](https://github.com/astrochun/github-stats-pages/tree/v0.2.0) (2021-02-27)

**Implemented enhancements:**
 - Include github-traffic-stats and use it [#13](http://github.com/astrochun/github-stats-pages/pull/13)

**Closed issues:**
 - Include github-traffic-stats and use it [#2](http://github.com/astrochun/github-stats-pages/issues/2)

**Merged pull requests:**
 - chore: add sponsorship [#15](https://github.com/astrochun/github-stats-pages/pull/15)


## [v0.1.5](https://github.com/astrochun/github-stats-pages/tree/v0.1.5) (2021-02-01)

**Implemented enhancements:**
 - Update setup.py to include additional classifier, README description [#12](http://github.com/astrochun/github-stats-pages/pull/12)

**Closed issues:**
 - Update setup.py to include additional classifier, README description [#11](http://github.com/astrochun/github-stats-pages/issues/11)


## [v0.1.4](https://github.com/astrochun/github-stats-pages/tree/v0.1.4) (2021-02-01)

**Implemented enhancements:**
 - Publish to PyPI using GitHub Actions [#10](http://github.com/astrochun/github-stats-pages/pull/10)

**Closed issues:**
 - Publish to PyPI using GitHub Actions [#9](http://github.com/astrochun/github-stats-pages/issues/9)


## [v0.1.3](https://github.com/astrochun/github-stats-pages/tree/v0.1.3) (2021-01-30)

**Bug fixes:**
 - Fix branch settings for GitHub badge [#7](http://github.com/astrochun/github-stats-pages/issues/7)

**Merged pull requests:**
 - Fix branch settings for GitHub badge [#8](http://github.com/astrochun/github-stats-pages/pull/8)


## [v0.1.2](https://github.com/astrochun/github-stats-pages/tree/v0.1.2) (2021-01-30)

**Fixed bugs:**
 - Add missing scripts in setup.py
 - Add python-package GitHub Actions for build and unit tests
 - Add GitHub badges to README.md
 - Update .gitignore to exclude .idea settings
 - Bump version: v0.1.0 -> v0.1.2


## [v0.1.1](https://github.com/astrochun/github-stats-pages/tree/v0.1.1) (2021-01-30)

**Fixed bugs:**
 - Correct path for github workflow [#4](http://github.com/astrochun/github-stats-pages/issues/4)

**Merged pull requests:**
 - Correct path for github workflow [#5](http://github.com/astrochun/github-stats-pages/pull/5)


## [v0.1.0](https://github.com/astrochun/github-stats-pages/tree/v0.1.0) (2021-01-30)

**Implemented enhancements:**
 - Get public repository lists [#3](http://github.com/astrochun/github-stats-pages/pull/3)

**Closed issues:**
 - GET list of public repositories for a user [#1](http://github.com/astrochun/github-stats-pages/issues/1)


<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/astrochun/github-stats-pages/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/pull/XX)

**Fixed bugs:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/issues/XX)

**Closed issues:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/issues/XX)

**Merged pull requests:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/pull/XX)

-->